@@ -9,5 +9,5 @@ SUBJECT_START_TOKEN = '<E>'
 NONE_REL_LABEL = 'None'
 NONE_REL_LABEL_ID = 0
 
-PARTIAL_LABEL = 'P'
+PARTIAL_LABEL = 'PARTIAL'
 PARTIAL_LABEL_ID = -1
