@@ -1,9 +1,12 @@
 # Copyright (c) Alibaba, Inc. and its affiliates.
 from .multilabel_typing_preprocessor import (
+    MultiLabelConcatTypingMCCEPreprocessor,
     MultiLabelConcatTypingPreprocessor,
     MultiLabelSpanTypingPreprocessor,
 )
 from .nlp_preprocessor import NLPPreprocessor
+from .pretraining_preprocessor import PretrainingPreprocessor
 from .relation_extraction_preprocessor import RelationExtractionPreprocessor
 from .sequence_labeling_preprocessor import SequenceLabelingPreprocessor
 from .span_extraction_preprocessor import SpanExtracionPreprocessor
+from .twostage_preprocessor import TwoStagePreprocessor
