@@ -1,5 +1,6 @@
 # Copyright (c) Alibaba, Inc. and its affiliates.
+from .pretraining_metric import PretrainingMetric
 from .relation_extraction_metric import RelationExtractionMetric
 from .sequence_labeling_metric import SequenceLabelingMetric
 from .span_extraction_metric import SpanExtractionMetric
-from .typing_metric import TypingMetric
+from .typing_metric import ConcatTypingThresholdMetric, TypingMetric
