@@ -1,5 +1,6 @@
 # Copyright (c) Alibaba, Inc. and its affiliates.
 from .base import DECODERS, Decoder, build_decoder
-from .crf import CRF
+from .crf import CRF, CRFwithConstraints
+from .mlm_head import OnlyMLMHead
 from .pairwise_crf import PairwiseCRF
 from .partial_crf import PartialCRF
